package com.ruoyi.project.check.mapper;

import java.util.List;
import com.ruoyi.project.check.domain.TCheckInstrument;

/**
 * 仪器Mapper接口
 *
 * @author ruoyi
 * @date 2022-11-22
 */
public interface TCheckInstrumentMapper
{
    /**
     * 查询仪器
     *
     * @param id 仪器主键
     * @return 仪器
     */
    public TCheckInstrument selectTCheckInstrumentById(Long id);

    /**
     * 查询仪器列表
     *
     * @param tCheckInstrument 仪器
     * @return 仪器集合
     */
    public List<TCheckInstrument> selectTCheckInstrumentList(TCheckInstrument tCheckInstrument);
    public List<TCheckInstrument> selectAllInstrument();

    /**
     * 新增仪器
     *
     * @param tCheckInstrument 仪器
     * @return 结果
     */
    public int insertTCheckInstrument(TCheckInstrument tCheckInstrument);

    /**
     * 修改仪器
     *
     * @param tCheckInstrument 仪器
     * @return 结果
     */
    public int updateTCheckInstrument(TCheckInstrument tCheckInstrument);

    /**
     * 删除仪器
     *
     * @param id 仪器主键
     * @return 结果
     */
    public int deleteTCheckInstrumentById(Long id);

    /**
     * 批量删除仪器
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTCheckInstrumentByIds(Long[] ids);
}
